==> heavyball-0.16.0.tar.gz: heavyball-0.16.0/heavyball/__init__.py <==
from .cached_psgd_kron import ForeachCachedPSGDKron
from .delayed_psgd import ForeachDelayedPSGD
from .foreach_adamw import ForeachAdamW
from .foreach_adopt import ForeachADOPT
from .foreach_laprop import ForeachLaProp
from .foreach_sfadamw import ForeachSFAdamW
from .foreach_soap import ForeachSOAP
from .p_adam import ForeachPaLMPAdam
from .palm_foreach_sfadamw import PaLMForeachSFAdamW
from .palm_foreach_soap import PaLMForeachSOAP
from .precond_schedule_foreach_soap import PrecondScheduleForeachSOAP
from .precond_schedule_palm_foreach_soap import PrecondSchedulePaLMForeachSOAP
from .precond_schedule_sfpsoap import PrecondScheduleSFPaLMSOAP
from .psgd_kron import ForeachPSGDKron
from .pure_psgd import ForeachPurePSGD
from .schedule_free_palm_foreach_soap import SFPaLMForeachSOAP

PalmForEachSoap = PaLMForeachSOAP

PaLMSOAP = PaLMForeachSOAP
PaLMSFAdamW = PaLMForeachSFAdamW
PaLMSFSoap = SFPaLMForeachSOAP
PaLMForeachSOAP = PaLMForeachSOAP
PrecondScheduleSFPaLMSOAP = PrecondScheduleSFPaLMSOAP
SOAP = ForeachSOAP
SFAdamW = ForeachSFAdamW
LaProp = ForeachLaProp
ADOPT = ForeachADOPT
PrecondScheduleForeachSOAP = PrecondScheduleForeachSOAP
PrecondSchedulePaLMForeachSOAP = PrecondSchedulePaLMForeachSOAP
PSGDKron = ForeachPSGDKron
AdamW = ForeachAdamW
PurePSGD = ForeachPurePSGD
PaLMPAdam = ForeachPaLMPAdam
DelayedPSGD = ForeachDelayedPSGD
CachedPSGDKron = ForeachCachedPSGDKron

__all__ = ['PalmForEachSoap', 'PaLMForeachSFAdamW', 'PaLMForeachSOAP', 'SFPaLMForeachSOAP', 'PrecondScheduleSFPaLMSOAP',
           'ForeachSOAP', 'ForeachSFAdamW', 'ForeachLaProp', 'ForeachADOPT', 'PrecondScheduleForeachSOAP',
           'PrecondSchedulePaLMForeachSOAP', 'ForeachPSGDKron', 'ForeachAdamW', 'ForeachPurePSGD', 'ForeachPaLMPAdam',
           'ForeachDelayedPSGD', 'ForeachCachedPSGDKron',  #
           'PaLMSOAP', 'PaLMSFAdamW', 'PaLMSFSoap', 'PaLMSFAdamW', 'PaLMForeachSOAP', 'PrecondScheduleSFPaLMSOAP',
           'SOAP', 'SFAdamW', 'LaProp', 'ADOPT', 'PSGDKron', 'AdamW', 'PurePSGD', 'PaLMPAdam', 'DelayedPSGD',
           'CachedPSGDKron']

==> heavyball-0.17.0.tar.gz: heavyball-0.17.0/heavyball/__init__.py <==
from .cached_psgd_kron import ForeachCachedPSGDKron
from .delayed_psgd import ForeachDelayedPSGD
from .foreach_adamw import ForeachAdamW
from .foreach_adopt import ForeachADOPT
from .foreach_laprop import ForeachLaProp
from .foreach_sfadamw import ForeachSFAdamW
from .foreach_soap import ForeachSOAP
from .p_adam import ForeachPaLMPAdam
from .palm_foreach_sfadamw import PaLMForeachSFAdamW
from .palm_foreach_soap import PaLMForeachSOAP
from .precond_schedule_foreach_soap import PrecondScheduleForeachSOAP
from .precond_schedule_palm_foreach_soap import PrecondSchedulePaLMForeachSOAP
from .precond_schedule_sfpsoap import PrecondScheduleSFPaLMSOAP
from .psgd_kron import ForeachPSGDKron
from .pure_psgd import ForeachPurePSGD
from .schedule_free_palm_foreach_soap import SFPaLMForeachSOAP
from .cached_delayed_psgd_kron import ForeachCachedDelayedPSGDKron

PalmForEachSoap = PaLMForeachSOAP

PaLMSOAP = PaLMForeachSOAP
PaLMSFAdamW = PaLMForeachSFAdamW
PaLMSFSoap = SFPaLMForeachSOAP
PaLMForeachSOAP = PaLMForeachSOAP
PrecondScheduleSFPaLMSOAP = PrecondScheduleSFPaLMSOAP
SOAP = ForeachSOAP
SFAdamW = ForeachSFAdamW
LaProp = ForeachLaProp
ADOPT = ForeachADOPT
PrecondScheduleForeachSOAP = PrecondScheduleForeachSOAP
PrecondSchedulePaLMForeachSOAP = PrecondSchedulePaLMForeachSOAP
PSGDKron = ForeachPSGDKron
AdamW = ForeachAdamW
PurePSGD = ForeachPurePSGD
PaLMPAdam = ForeachPaLMPAdam
DelayedPSGD = ForeachDelayedPSGD
CachedPSGDKron = ForeachCachedPSGDKron
CachedDelayedPSGDKron

__all__ = ['PalmForEachSoap', 'PaLMForeachSFAdamW', 'PaLMForeachSOAP', 'SFPaLMForeachSOAP', 'PrecondScheduleSFPaLMSOAP',
           'ForeachSOAP', 'ForeachSFAdamW', 'ForeachLaProp', 'ForeachADOPT', 'PrecondScheduleForeachSOAP',
           'PrecondSchedulePaLMForeachSOAP', 'ForeachPSGDKron', 'ForeachAdamW', 'ForeachPurePSGD', 'ForeachPaLMPAdam',
           'ForeachDelayedPSGD', 'ForeachCachedPSGDKron', 'ForeachCachedDelayedPSGDKron'  #
           'PaLMSOAP', 'PaLMSFAdamW', 'PaLMSFSoap', 'PaLMSFAdamW', 'PaLMForeachSOAP', 'PrecondScheduleSFPaLMSOAP',
           'SOAP', 'SFAdamW', 'LaProp', 'ADOPT', 'PSGDKron', 'AdamW', 'PurePSGD', 'PaLMPAdam', 'DelayedPSGD',
           'CachedPSGDKron', 'CachedDelayedPSGDKron']
